@@ -6,9 +6,9 @@ from __future__ import annotations
 
 import datetime
 import importlib
-import inspect
-import sys
+import ssl
 from concurrent import futures
+from importlib.metadata import entry_points
 from io import BytesIO
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, BinaryIO, ClassVar, cast
@@ -32,12 +32,6 @@ from mkdocstrings._internal.handlers.rendering import (
 from mkdocstrings._internal.inventory import Inventory
 from mkdocstrings._internal.loggers import get_logger, get_template_logger
 
-# YORE: EOL 3.9: Replace block with line 4.
-if sys.version_info < (3, 10):
-    from importlib_metadata import entry_points
-else:
-    from importlib.metadata import entry_points
-
 if TYPE_CHECKING:
     from collections.abc import Iterable, Iterator, Mapping, Sequence
 
@@ -103,21 +97,15 @@ class BaseHandler:
     To add custom CSS, add an `extra_css` variable or create an 'style.css' file beside the templates.
     """
 
-    # YORE: Bump 1: Replace ` = ""` with `` within line.
-    name: ClassVar[str] = ""
+    name: ClassVar[str]
     """The handler's name, for example "python"."""
 
-    # YORE: Bump 1: Replace ` = ""` with `` within line.
-    domain: ClassVar[str] = ""
+    domain: ClassVar[str]
     """The handler's domain, used to register objects in the inventory, for example "py"."""
 
     enable_inventory: ClassVar[bool] = False
     """Whether the inventory creation is enabled."""
 
-    # YORE: Bump 1: Remove block.
-    fallback_config: ClassVar[dict] = {}
-    """Fallback configuration when searching anchors for identifiers."""
-
     fallback_theme: ClassVar[str] = ""
     """Fallback theme to use when a template isn't found in the configured theme."""
 
@@ -126,16 +114,11 @@ class BaseHandler:
 
     def __init__(
         self,
-        # YORE: Bump 1: Remove line.
-        *args: Any,
-        # YORE: Bump 1: Remove line.
-        **kwargs: Any,
-        # YORE: Bump 1: Replace `# ` with `` within block.
-        # *,
-        # theme: str,
-        # custom_templates: str | None,
-        # mdx: Sequence[str | Extension],
-        # mdx_config: Mapping[str, Any],
+        *,
+        theme: str,
+        custom_templates: str | None,
+        mdx: Sequence[str | Extension],
+        mdx_config: Mapping[str, Any],
     ) -> None:
         """Initialize the object.
 
@@ -148,58 +131,6 @@ class BaseHandler:
             mdx (list[str | Extension]): A list of Markdown extensions to use.
             mdx_config (Mapping[str, Mapping[str, Any]]): Configuration for the Markdown extensions.
         """
-        # YORE: Bump 1: Remove block.
-        handler = ""
-        theme = ""
-        custom_templates = None
-        if args:
-            handler, args = args[0], args[1:]
-        if args:
-            theme, args = args[0], args[1:]
-            warn(
-                "The `theme` argument must be passed as a keyword argument.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        if args:
-            custom_templates, args = args[0], args[1:]
-            warn(
-                "The `custom_templates` argument must be passed as a keyword argument.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        handler = kwargs.pop("handler", handler)
-        theme = kwargs.pop("theme", theme)
-        custom_templates = kwargs.pop("custom_templates", custom_templates)
-        mdx = kwargs.pop("mdx", None)
-        mdx_config = kwargs.pop("mdx_config", None)
-        if handler:
-            if not self.name:
-                type(self).name = handler
-            warn(
-                "The `handler` argument is deprecated. The handler name must be specified as a class attribute.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        if not self.domain:
-            warn(
-                "The `domain` attribute must be specified as a class attribute.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        if mdx is None:
-            warn(
-                "The `mdx` argument must be provided (as a keyword argument).",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        if mdx_config is None:
-            warn(
-                "The `mdx_config` argument must be provided (as a keyword argument).",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
         self.theme = theme
         """The selected theme."""
         self.custom_templates = custom_templates
@@ -219,16 +150,14 @@ class BaseHandler:
 
         # add extended theme templates
         extended_templates_dirs = self.get_extended_templates_dirs(self.name)
-        for templates_dir in extended_templates_dirs:
-            paths.append(templates_dir / self.theme)
+        paths.extend(templates_dir / self.theme for templates_dir in extended_templates_dirs)
 
         # add fallback theme templates
         if self.fallback_theme and self.fallback_theme != self.theme:
             paths.append(themes_dir / self.fallback_theme)
 
             # add fallback theme of extended templates
-            for templates_dir in extended_templates_dirs:
-                paths.append(templates_dir / self.fallback_theme)
+            paths.extend(templates_dir / self.fallback_theme for templates_dir in extended_templates_dirs)
 
         for path in paths:
             css_path = path / "style.css"
@@ -310,7 +239,7 @@ class BaseHandler:
 
         Arguments:
             identifier: An identifier for which to collect data. For example, in Python,
-                it would be 'mkdocstrings.handlers' to collect documentation about the handlers module.
+                it would be 'mkdocstrings.BaseHandler' to collect documentation about the BaseHandler class.
                 It can be anything that you can feed to the tool of your choice.
             options: The final configuration options.
 
@@ -430,24 +359,24 @@ class BaseHandler:
         global _markdown_conversion_layer  # noqa: PLW0603
         _markdown_conversion_layer += 1
         treeprocessors = self.md.treeprocessors
-        treeprocessors[HeadingShiftingTreeprocessor.name].shift_by = heading_level  # type: ignore[attr-defined]
-        treeprocessors[IdPrependingTreeprocessor.name].id_prefix = html_id and html_id + "--"  # type: ignore[attr-defined]
-        treeprocessors[ParagraphStrippingTreeprocessor.name].strip = strip_paragraph  # type: ignore[attr-defined]
+        treeprocessors[HeadingShiftingTreeprocessor.name].shift_by = heading_level
+        treeprocessors[IdPrependingTreeprocessor.name].id_prefix = html_id and html_id + "--"
+        treeprocessors[ParagraphStrippingTreeprocessor.name].strip = strip_paragraph
         if BacklinksTreeProcessor.name in treeprocessors:
-            treeprocessors[BacklinksTreeProcessor.name].initial_id = html_id  # type: ignore[attr-defined]
-
-        if autoref_hook:
-            self.md.inlinePatterns[AutorefsInlineProcessor.name].hook = autoref_hook  # type: ignore[attr-defined]
+            treeprocessors[BacklinksTreeProcessor.name].initial_id = html_id
+        if autoref_hook and AutorefsInlineProcessor.name in self.md.inlinePatterns:
+            self.md.inlinePatterns[AutorefsInlineProcessor.name].hook = autoref_hook  # ty: ignore[unresolved-attribute]
 
         try:
             return Markup(self.md.convert(text))
         finally:
-            treeprocessors[HeadingShiftingTreeprocessor.name].shift_by = 0  # type: ignore[attr-defined]
-            treeprocessors[IdPrependingTreeprocessor.name].id_prefix = ""  # type: ignore[attr-defined]
-            treeprocessors[ParagraphStrippingTreeprocessor.name].strip = False  # type: ignore[attr-defined]
+            treeprocessors[HeadingShiftingTreeprocessor.name].shift_by = 0
+            treeprocessors[IdPrependingTreeprocessor.name].id_prefix = ""
+            treeprocessors[ParagraphStrippingTreeprocessor.name].strip = False
             if BacklinksTreeProcessor.name in treeprocessors:
-                treeprocessors[BacklinksTreeProcessor.name].initial_id = None  # type: ignore[attr-defined]
-            self.md.inlinePatterns[AutorefsInlineProcessor.name].hook = None  # type: ignore[attr-defined]
+                treeprocessors[BacklinksTreeProcessor.name].initial_id = None
+            if AutorefsInlineProcessor.name in self.md.inlinePatterns:
+                self.md.inlinePatterns[AutorefsInlineProcessor.name].hook = None
             self.md.reset()
             _markdown_conversion_layer -= 1
 
@@ -532,20 +461,11 @@ class BaseHandler:
         self._headings.clear()
         return result
 
-    # YORE: Bump 1: Replace `*args: Any, **kwargs: Any` with `config: Any`.
-    def update_env(self, *args: Any, **kwargs: Any) -> None:  # noqa: ARG002
+    def update_env(self, config: Any) -> None:
         """Update the Jinja environment."""
-        # YORE: Bump 1: Remove line.
-        warn("No need to call `super().update_env()` anymore.", DeprecationWarning, stacklevel=2)
 
     def _update_env(self, md: Markdown, *, config: Any | None = None) -> None:
         """Update our handler to point to our configured Markdown instance, grabbing some of the config from `md`."""
-        # YORE: Bump 1: Remove block.
-        if self.mdx is None and config is not None:
-            self.mdx = config.get("mdx", None) or config.get("markdown_extensions", None) or ()
-        if self.mdx_config is None and config is not None:
-            self.mdx_config = config.get("mdx_config", None) or config.get("mdx_configs", None) or {}
-
         extensions: list[str | Extension] = [*self.mdx, MkdocstringsInnerExtension(self._headings)]
 
         new_md = Markdown(extensions=extensions, extension_configs=self.mdx_config)
@@ -553,24 +473,18 @@ class BaseHandler:
         # MkDocs adds its own (required) extension that's not part of the config. Propagate it.
         if "relpath" in md.treeprocessors:
             relpath = md.treeprocessors["relpath"]
-            new_relpath = type(relpath)(relpath.file, relpath.files, relpath.config)  # type: ignore[attr-defined,call-arg]
+            new_relpath = type(relpath)(relpath.file, relpath.files, relpath.config)
             new_md.treeprocessors.register(new_relpath, "relpath", priority=0)
+        elif "zrelpath" in md.treeprocessors:
+            zrelpath = md.treeprocessors["zrelpath"]
+            new_zrelpath = type(zrelpath)(new_md, zrelpath.path, zrelpath.use_directory_urls)
+            new_md.treeprocessors.register(new_zrelpath, "zrelpath", priority=0)
 
         self._md = new_md
 
         self.env.filters["highlight"] = Highlighter(new_md).highlight
 
-        # YORE: Bump 1: Replace block with `self.update_env(config)`.
-        parameters = inspect.signature(self.update_env).parameters
-        if "md" in parameters:
-            warn(
-                "The `update_env(md)` parameter is deprecated. Use `self.md` instead.",
-                DeprecationWarning,
-                stacklevel=1,
-            )
-            self.update_env(new_md, config)
-        elif "config" in parameters:
-            self.update_env(config)
+        self.update_env(config)
 
 
 class Handlers:
@@ -623,35 +537,6 @@ class Handlers:
 
         self._inv_futures: dict[futures.Future, tuple[BaseHandler, str, Any]] = {}
 
-    # YORE: Bump 1: Remove block.
-    def get_anchors(self, identifier: str) -> tuple[str, ...]:
-        """Return the canonical HTML anchor for the identifier, if any of the seen handlers can collect it.
-
-        Arguments:
-            identifier: The identifier (one that [collect][mkdocstrings.BaseHandler.collect] can accept).
-
-        Returns:
-            A tuple of strings - anchors without '#', or an empty tuple if there isn't any identifier familiar with it.
-        """
-        for handler in self._handlers.values():
-            try:
-                if hasattr(handler, "get_anchors"):
-                    warn(
-                        "The `get_anchors` method is deprecated. "
-                        "Declare a `get_aliases` method instead, accepting a string (identifier) "
-                        "instead of a collected object.",
-                        DeprecationWarning,
-                        stacklevel=1,
-                    )
-                    aliases = handler.get_anchors(handler.collect(identifier, getattr(handler, "fallback_config", {})))
-                else:
-                    aliases = handler.get_aliases(identifier)
-            except CollectionError:
-                continue
-            if aliases:
-                return aliases
-        return ()
-
     def get_handler_name(self, config: dict) -> str:
         """Return the handler name defined in an "autodoc" instruction YAML configuration, or the global default handler.
 
@@ -677,7 +562,7 @@ class Handlers:
     def get_handler(self, name: str, handler_config: dict | None = None) -> BaseHandler:
         """Get a handler thanks to its name.
 
-        This function dynamically imports a module named "mkdocstrings.handlers.NAME", calls its
+        This function dynamically imports a module named "mkdocstrings_handlers.NAME", calls its
         `get_handler` method to get an instance of a handler, and caches it in dictionary.
         It means that during one run (for each reload when serving, or once when building),
         a handler is instantiated only once, and reused for each "autodoc" instruction asking for it.
@@ -695,34 +580,14 @@ class Handlers:
                 handler_config = self._handlers_config.get(name, {})
             module = importlib.import_module(f"mkdocstrings_handlers.{name}")
 
-            # YORE: Bump 1: Remove block.
-            kwargs = {
-                "theme": self._theme,
-                "custom_templates": self._custom_templates,
-                "mdx": self._mdx,
-                "mdx_config": self._mdx_config,
-                "handler_config": handler_config,
-                "tool_config": self._tool_config,
-            }
-            if "config_file_path" in inspect.signature(module.get_handler).parameters:
-                kwargs["config_file_path"] = self._tool_config.get("config_file_path")
-                warn(
-                    "The `config_file_path` argument in `get_handler` functions is deprecated. "
-                    "Use `tool_config.get('config_file_path')` instead.",
-                    DeprecationWarning,
-                    stacklevel=1,
-                )
-            self._handlers[name] = module.get_handler(**kwargs)
-
-            # YORE: Bump 1: Replace `# ` with `` within block.
-            # self._handlers[name] = module.get_handler(
-            #     theme=self._theme,
-            #     custom_templates=self._custom_templates,
-            #     mdx=self._mdx,
-            #     mdx_config=self._mdx_config,
-            #     handler_config=handler_config,
-            #     tool_config=self._tool_config,
-            # )
+            self._handlers[name] = module.get_handler(
+                theme=self._theme,
+                custom_templates=self._custom_templates,
+                mdx=self._mdx,
+                mdx_config=self._mdx_config,
+                handler_config=handler_config,
+                tool_config=self._tool_config,
+            )
         return self._handlers[name]
 
     def _download_inventories(self) -> None:
@@ -736,7 +601,7 @@ class Handlers:
         for handler_name, conf in self._handlers_config.items():
             handler = self.get_handler(handler_name)
 
-            if handler.get_inventory_urls.__func__ is BaseHandler.get_inventory_urls:  # type: ignore[attr-defined]
+            if handler.get_inventory_urls.__func__ is BaseHandler.get_inventory_urls:
                 if inv_configs := conf.pop("import", ()):
                     warn(
                         "mkdocstrings v1 will stop handling 'import' in handlers configuration. "
@@ -753,6 +618,11 @@ class Handlers:
             to_download.extend((handler, url, conf) for url, conf in inv_configs)
 
         if to_download:
+            # YORE: EOL 3.12: Remove block.
+            # NOTE: Create context in main thread to fix issue
+            # https://github.com/mkdocstrings/mkdocstrings/issues/796.
+            _ = ssl.create_default_context()
+
             thread_pool = futures.ThreadPoolExecutor(4)
             for handler, url, conf in to_download:
                 _logger.debug("Downloading inventory from %s", url)
@@ -773,7 +643,7 @@ class Handlers:
             for fut, (handler, url, conf) in reversed(self._inv_futures.items()):
                 try:
                     yield from handler.load_inventory(BytesIO(fut.result()), url, **conf)
-                except Exception as error:  # noqa: BLE001
+                except Exception as error:  # noqa: BLE001,PERF203
                     _logger.error("Couldn't load inventory %s through handler '%s': %s", url, handler.name, error)  # noqa: TRY400
             self._inv_futures = {}
 
